@@ -360,6 +360,7 @@ amap_struct_triggers *read_file_triggers(char *extension, char *filename, amap_s
             }
             b++;
           }
+          ptr[b] = 0;
           trigger->trigger = amap_strdup(ptr);
           trigger->trigger_length = strlen(trigger->trigger);
           free(ptr);
@@ -1140,7 +1141,7 @@ void amap_check_connects(amap_struct_coms *coms, amap_struct_scaninfo *scaninfo,
         error = 0;
         if (getsockopt(coms[i].socket, SOL_SOCKET, SO_ERROR, &error, &error_len) < 0 || error != 0) {
           if (coms[i].port->skip < 1 && (opt->portscanner == 0 || opt->verbose) && opt->quiet == 0)
-            amap_warn("Could not connect (unreachable) to %s:%d/%s, disabling port", coms[i].target->target, coms[i].port->port, coms[i].port->ip_prot == AMAP_PROTO_TCP ? "tcp" : "udp");
+            amap_warn("Could not connect (unreachable) to %s:%d/%s, disabling port (EUNKN)", coms[i].target->target, coms[i].port->port, coms[i].port->ip_prot == AMAP_PROTO_TCP ? "tcp" : "udp");
           coms[i].port->skip = 2;
           close(coms[i].socket);
           memset(&coms[i], 0, sizeof(amap_struct_coms));
@@ -1295,11 +1296,16 @@ void amap_check_connects(amap_struct_coms *coms, amap_struct_scaninfo *scaninfo,
           if ((ssl = SSL_new(sslContext)) == NULL)
             amap_error("could not prepare SSL context, you've got severe memory problems here");
           SSL_set_fd(ssl, coms[i].socket);
-          if (SSL_connect(ssl) < 0) {
+          fcntl(coms[i].socket, F_SETFL, fcntl(coms[i].socket, F_GETFL) &~ O_NONBLOCK);
+          if ((error = SSL_connect(ssl)) < 0) {
+            if (opt->verbose > 2)
+              printf("SSL connection failed\n");
             shutdown(coms[i].socket, SHUT_RDWR);
             close(coms[i].socket);
             coms[i].active = AMAP_CONNECT_RETRY;
           } else {
+            if (opt->verbose > 2)
+              printf("SSL connection succeeded\n");
             coms[i].ssl_socket = ssl;
             coms[i].active = AMAP_CONNECT_READY;
             coms[i].ssl_enabled = 1;
